@@ -27,7 +27,7 @@ def create_object(request, model=None, form_class=None, login_required=False,
             return DojoDataJSONResponse(new_obj, fields=fields, exclude_fields=\
                 exclude_fields, add_model_info=add_model_info, status=201)
         else:
-            return HttpResponseBadRequest()
+            return HttpResponseBadRequest(content=form.errors)
     else:
         return HttpResponseNotAllowed()
 
@@ -259,7 +259,7 @@ def object_list_filtered_by_fk(request, related_object_id,
     else:
         return HttpResponseNotAllowed()
         
-def restful_dispatcher(request, model, form_class, object_id=None,
+def restful_dispatcher(request, model, form_class=None, object_id=None,
     login_required=False, fields=(), exclude_fields=(), add_model_info=False):
     """
     Dispatches requests in a RESTful manner.
